Installing scRFE
=========================

PyPI
~~~~~~~~~
scRFE is available through the `Python Package Index`_ and thus can be installed
using pip. To install scRFE using pip, run:

.. code:: bash

	pip install scRFE

.. _Python Package Index: https://pypi.python.org/pypi


Development Version
~~~~~~~~~~~~~~~~~~~~~~~~~~~
The lastest verion of scRFE is on `GitHub
<https://github.com/czbiohub/scRFE/>`__

.. code:: bash

	git clone https://github.com/czbiohub/scRFE.git
